@@ -11,9 +11,9 @@ def readFile(path: str) -> str:
     return temp
 readFile.__doc__ = 'A function to read an entire file into a string'
 
-def readListFile(path: str, sep: str) -> list:
+def readListFile(path: str, sep='\n') -> list:
     temp = None
-    with open(path, "r") as f:
+    with open(path, 'r') as f:
         temp = f.read().split(sep)
     return temp
 readListFile.__doc__ = 'A function to read sections of a file seperated by \'sep\' into a list'
